… | OiRA

Help

1. Priprema
2. Uključite
3. Prepoznavanje + procjena
   1. 1 Commercial manned guarding
   2. Ω Ostali izvori opasnosti, štetnosti i napora
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Neodgovoren
   - Odgođen
   - Rizik ne postoji
   - Postoji rizik
4. Plan mjera
5. Završni dokumenti
6. Status 0%

## Opišite rizik…

Je li rizik prihvatljiv? Ne, potrebno je više mjera Da, preostali rizik je prihvatljiv

Select the priority of this risk Low Medium High
Informacija
Učitajte slikulabel_upload_image
Komentari

Scroll to top
Back

## add-risk.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More